/*
 * 	MSP430G2452 USI I2C-Master Example
 *
 *	Eng: This code is an simple I2C-master example for MSP430G2452 MCU
 *		 for reading distance values from SFR02 ultrasonic rangefinder.
 *		 Chip is connected as shown below and the communication is done
 *		 with I2C-bus.
 *
 * 	Fin: Yksinkertainen esimerkki, kuinka SFR02 ultranianturilta voidaan lukea
 * 		 etisyystietoa I2C-vyln avulla.
 *
 * Note:
 * 		Change user settings whatever is needed and use the functions provided. It is recommended
 * 		to set the correct device in the project settings, because underlying USI-I2C includes only
 * 		<msp430.h> -library rather than a specific device.
 *
 *		32kHz crystal is required!
 *
 * About:
 * 		This code is written on Windows 7 using Code Composer Studio v5. When
 * 		you change the code, it is recommended to ReBuild instead of Building or
 * 		do Clean -> Build.
 *
 *
 *		MASTER 						  			SLAVE
 *				               GND
 *				            	|
 *		MSP430G2452	           | | 22k            SFR02
 * 	 	 ______                | |                ______
 * 		|      |             	|		+5V------|      |
 * 		|  P1.7|----------------^---- SDA -------|      |
 * 		|  P1.6|----------------,---  SCL -------|      |
 *	    |      | 	            |	  GND -------|      |
 *	 	|	   |	           | |   			 |______|
 *	 	|      |               | | 22k
 *	 	|      |                |
 *	 	|      |                 `-----GND
 *		|______|
 *
 *	Note! Resistors are important since they protect the MCU from 5V. 22k resistors cause
 *		  datalines to go about 3,3 volts when not pulled to ground. +5V is taken
 *		  from Launchpad (USB-Voltage).
 *
 *	Huom! Vastukset ovat trkeit, koska SFR02 kytt 5 voltin logiikkajnnitett.
 *	      Nill vastuksilla lasketaan jnnite 3,3 voltin tasolle ja suojataan MCU:ta. 5 voltin
 *	      jnnite on otettu Launchpadilta (USB-jnnite).
 *
 *
 * 	Tarkemmat tiedot / More information:
 *	http://www.hutasu.net/index.php?sivu_id=119&parent=8
 *
 **/

#include <msp430.h> 
#include "Launchpad/launchpad.h"
#include "USI/USI.h"
#include "Launchpad/UART.h"
#include "printf/printf.h"

int main(void)
{
	char SFR02_online;

	// vahtikoiratimerin pysytys
	WDTCTL = WDTPW | WDTHOLD;

	// Pinnien alustus
	InitGPIO();

    // sallitaan globaali keskeytys
    __enable_interrupt();

    // Uartin alustus
    TimerA_UART_init();

	// Usin alustus
	InitUSI();

    while(1)
	{
    	// Printataan ett ollaan valmiita
    	printf("\n\rMaster Ready!\n\r");

    	// Tutkitaan onko anturi paikalla
    	SFR02_online = CheckForSlaveExists(0xE0);

    	// Jos anturi on paikalla, asetetaan punainen LED plle. Vihre ei kannata kytt,
    	// koska se on kytketty P1.6-pinniin, joka on SCL-linja.
    	if(SFR02_online == 1)
    	{
    		printf("SFR02 online!");
    		LED_RED_ON;
    	}
    	else
    	{
    		printf("SFR02 offline!");
    		LED_RED_OFF;
    	}

    	// Nukuskellaan 1 sekunti (vaihtoehtoina kaksi eri funktiota joita voi kytt)
    	//TimerA_msDelay(1000);
    	TimerA_Delay(1);

	}
}




// Portin 2 keskeytysvektori
#pragma vector=PORT2_VECTOR
__interrupt void ISR_PORT2(void)
{

}


// AD-muunnin keskeytysvektori
#pragma vector=ADC10_VECTOR
__interrupt void ADC_ISR(void)
{

}

// Timer_A2 Interrupt Vector (TAIV) handler
// TimerA1 keskeytykset ja CCR1 ohjautuu tnne. Printtaus menee
// TIMER0_A0_VECTOR keskeytykseen joka on UART.c:ss.
#pragma vector=TIMER0_A1_VECTOR
__interrupt void Timer_A1(void)
{

}


